@@ -7,6 +7,11 @@ class SelectorColor(ft.Container):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.expand = True
+        self.width = 800
+        self.border_radius = 15
+        self.border = ft.border.all(1, "grey800")
+        self.alignment = ft.alignment.top_center
+        self.padding = 20
         self.GetArquivo()
 
         self.slides = {
@@ -15,11 +20,14 @@ class SelectorColor(ft.Container):
                 max=255, 
                 value=0,
                 height=30, 
-                width=320,                
+                width=305,                
                 active_color="#00ADFF",
                 thumb_color ="#00ADFF",
                 inactive_color="#205049",
-                on_change=self.update_color,                 
+                on_change=self.update_color,  
+                overlay_color = 'trasparent',
+                col = 11,   
+                expand=True,            
             ) 
             for l in ['r', 'g', 'b']
         }
@@ -76,14 +84,18 @@ class SelectorColor(ft.Container):
                    
                 ],
                 horizontal_alignment='center',
-                tight=True,
+                alignment='center',
+                # tight=True,
                 spacing= 3,
+                expand=True,
             ),
-            alignment=ft.alignment.top_center,
+            alignment=ft.alignment.center,
             width=260, 
             height=210, 
             border_radius=12,
             bgcolor="#0000ff",
+            expand_loose=True,
+            col =  {'xs':12, 'sm':5},
 
             )
         
@@ -127,40 +139,24 @@ class SelectorColor(ft.Container):
 
 
         legenda = {
-            'primary': 'primary: texto principal, fundo filledbutton, texto outlinedbutton, slider,  preenchimento do switch e checkbox, icone,  texto do elevatebuton',
-            'on_primary': 'on_primary: texto filledbutton e bolinha do swicth com True',
-            'on_secondary_container': 'on_secondary_container: texto filledtonalbutton',
-            'outline': 'outline: borda do outliedbutton',
-            'shadow': 'shadow: sombras',
-            'on_surface_variant': 'on_surface_variant: labels, cor da caixa do checkbox e cor do check do popMenubutton',
-            'surface_variant': 'surface_variant: slider e fundo do texfield e do dropbox',
-            'primary_container': 'primary_container: HOVERED da bolinha do switch',
-            'on_surface': 'on_surface: HOVERED do checkbox e cor dos items do popmenubuton',
-            'surface': 'surface: cor de fundo',
+            'primary': 'texto principal, fundo filledbutton, texto outlinedbutton, slider true,  preenchimento do switch, checkbox True, icone,  texto do elevatebuton',
+            'on_primary': 'texto filledbutton e bolinha do swicth com True',
+            'on_secondary_container': 'texto filledtonalbutton',
+            'outline': 'borda do outliedbutton',
+            'shadow': 'sombras',
+            'on_surface_variant': 'labels, hint do texfied, caixa do checkbox, check do popMenubutton, bolinha False do switch',
+            'surface_variant': 'slider false, fundo do texfield e do dropdown quando filled = true, switch false',
+            'primary_container': ' HOVERED da bolinha do switch',
+            'on_surface': 'HOVERED do checkbox,items do popmenubuton, borda do Dropdown',
+            'surface': 'fundo',
+            "surface_container_low":  'fundo do card',
+            "outline_variant":'divider',
+            "secondary_container": 'prograss_bar False',
+            "Boddy_large": 'Texto do TextField e Dropdown quando dense = true',
+            "Boddy_medium": 'Texto do TextField e Dropdown quando dense = false',
   
 
         }
-        # self.tabela_legenda = ft.DataTable(
-        #     column_spacing = 10,
-        #     data_row_max_height=80,
-        #     columns=[ft.DataColumn(ft.Text(i, weight='BOLD')) for i in ['Cor', 'Descrição']],
-        #     rows=[
-        #         ft.DataRow(
-        #             cells=[
-        #                 ft.DataCell(
-        #                     ft.Text(linha)
-        #                 ),
-        #                 ft.DataCell(
-        #                     ft.Text(legenda[linha])
-        #                 )
-        #             ]
-        #         ) 
-        #         for linha in legenda.keys()
-        #     ],
-        #     border = ft.border.all(1, 'primary'),
-        #     vertical_lines = ft.BorderSide(1, 'primary'),
-        #     heading_row_color = 'grey800',
-        # )
 
         self.tabela_legenda = ft.Column(
             controls = [
@@ -169,7 +165,7 @@ class SelectorColor(ft.Container):
                         [
                             ft.Text(i, weight='BOLD',width=160,text_align='center', color="#CADCBA"),
                             ft.VerticalDivider(10, color='primary,0.5'),
-                            ft.Text(legenda[i],width=220,color="#BEBCE7")
+                            ft.Text(legenda[i],width=220,color="#BEBCE7", expand=True),
                         ],
                         spacing=0,
                     ),
@@ -183,23 +179,31 @@ class SelectorColor(ft.Container):
             spacing=0,
             run_spacing=0,
             scroll=ft.ScrollMode.ADAPTIVE,
-            width=400,
-            # expand=True,
+            # width=400,
+            visible=False,
+            expand=True,
         )
 
         self.objetos = ft.Dropdown(
             width=350,
+            menu_width =200,
             options=[ft.dropdown.Option(i) for i in self.datas.keys()],
             hint_text="Selecione o objeto",
+            dense=True,
             filled=True,
             fill_color='grey900',
+            border_color='grey800',
+            border_width=1,
             border_radius=15,
             on_change=self.SetObjeto,
             enable_filter = True,
             enable_search = True,
-            editable=True
-            
+            editable=True,
+            col = 11,            
         )
+      
+
+     
 
         self.cor = 'black'
 
@@ -209,13 +213,24 @@ class SelectorColor(ft.Container):
             on_click=self.ExportarCores,
             bgcolor='grey800',
             color="#B0B3B1",
+            col = {'xs':12, 'sm':4},
+        )
+        self.btn_save = ft.FilledButton(
+            'Salvar Tema', 
+            bgcolor='grey800', 
+            on_click=self.TornarVizivel,
+            color="#B0B3B1"
         )
-        self.btn_save = ft.FilledButton('Salvar Tema', bgcolor='grey800', on_click=self.TornarVizivel,color="#B0B3B1",)
         self.nome_tema = ft.TextField(
             hint_text='Digite o nome do tema',
+            hint_style=ft.TextStyle(color='grey300'),
+            text_style=ft.TextStyle(color='grey300'),
             col=96,
             border_width=1,
+            border_color='grey800',
             border_radius=15,
+            fill_color='grey900',
+            filled=True,
             dense=True,
             content_padding=ft.Padding(5, 0, 0, 25),
             height=40,
@@ -223,10 +238,8 @@ class SelectorColor(ft.Container):
             expand=True,
             suffix=ft.Row(
                 [
-                    ft.IconButton(
-                        ft.Icons.SAVE,  tooltip='Confirmar', on_click=self.Salvar),
-                    ft.IconButton(ft.Icons.CANCEL,on_click=self.Cancelar,
-                                   tooltip='Cancelar'),
+                    ft.IconButton(ft.Icons.SAVE,  tooltip='Confirmar', on_click=self.Salvar,icon_color='grey600'),
+                    ft.IconButton(ft.Icons.CANCEL,on_click=self.Cancelar,icon_color='grey600',tooltip='Cancelar'),
                 ],
                 spacing=0,
                 tight=True,
@@ -236,10 +249,18 @@ class SelectorColor(ft.Container):
 
         self.tema_escolhido = ft.Dropdown(
             hint_text='Selecione um tema',
-            width=300,
+            hint_style=ft.TextStyle(color='grey300'),         
+            width=500,
+            menu_width = 200,
+            
+            dense=True,
             filled=True,
             fill_color='grey900', 
-            border_radius=15,          
+            border_color='grey800',
+            border_radius=15, 
+            border_width=1,
+            col ={'xs':12, 'sm':8},
+            expand=True,         
             
             options = [
                 ft.dropdown.Option(i)
@@ -248,54 +269,148 @@ class SelectorColor(ft.Container):
             on_change=self.CarregarTema
         )
 
-
-        self.content = ft.Row(
-            controls = [                                                      
-                self.color_box2,
-                ft.Container(
-                    content = ft.Column(
+        """
+        xs	<576px
+        sm	≥576px
+        md	≥768px
+        lg	≥992px
+        xl	≥1200px
+        xxl ≥1400px
+        """
+        cols = {
+            "xs": 24,"sm": 24,"md": 24,
+            "lg": 24,"xl": 24,"xxl": 24,
+        }
+        self.exibir_legendas = ft.Checkbox(
+            label="Exibir legendas" if not self.tabela_legenda.visible else "Ocultar legendas",
+            label_style = ft.TextStyle(color = "#BEBCE7"),
+            # fill_color = 'grey500,0.1',
+            # border_side = ft.border.all(5, ft.Colors.BLUE),
+            # check_color = 'white',
+            # active_color = 'white',
+            on_change=self.ExibirLegendas,
+            value=False,
+        )
+        self.icone_copy  = ft.IconButton(
+            icon=ft.Icons.COPY, 
+            icon_size = 10,                                       
+            splash_radius=0,
+            icon_color='white',
+            on_click=lambda e: e.page.set_clipboard(f'"{self.cor}"'),
+            col = 1,
+        )
+        self.controles = ft.Container(
+            content = ft.Column(
+                [
+                    ft.ResponsiveRow(
                         [
-                            ft.Row([self.ativar_sombras, self.ativar_bordas, self.ativar_gradiente], alignment='center', spacing=1,wrap=False),
-                            ft.Row(
-                                    [
-                                   self.objetos,
-                                    ft.IconButton(
-                                        icon=ft.Icons.COPY, 
-                                        icon_size = 10,                                       
-                                        splash_radius=0,
-                                        icon_color='white',
-                                        on_click=lambda e: e.page.set_clipboard(f'"{self.cor}"')
-                                    )
-                                ], 
-                                spacing = 0,
-                                wrap=False,                                       
-                            ),                                    
-                            ft.Row([ft.Text("Vermelho", selectable=True, width=70, color="#BEBCE7"),self.slides[f'r'],], spacing=0),
-                            ft.Row([ft.Text("Verde", selectable=True, width=70, color="#BEBCE7"),self.slides[f'g'],], spacing=0),
-                            ft.Row([ft.Text("Azul", selectable=True, width=70, color="#BEBCE7"),self.slides[f'b'],], spacing=0),
-                        ],
-                        width=380,
-                        spacing=0,
-                        run_spacing=0,
-                        horizontal_alignment='center',
+                            self.ativar_sombras, 
+                            self.ativar_bordas, 
+                            self.ativar_gradiente,
+                            self.exibir_legendas,
+                        ], 
+                        alignment='center', 
+                        spacing=1,
+                        run_spacing=1,
+                        # wrap=False
+                        columns=24,
                     ),
-                    border=ft.border.all(1, 'grey800'),
-                    border_radius=15,
-                    padding=20,
-                ),
-                ft.Row([self.btn_exportar_cores, self.tema_escolhido], alignment='center',),
-                self.tabela_legenda,   
-                
-                ft.Row([self.btn_save,self.nome_tema,], alignment='center',), 
-                                                                      
-            ], 
-            wrap=True,
-            spacing=20,
-            run_spacing=10,
-            alignment='center',
-            vertical_alignment='center',
+                    ft.ResponsiveRow(
+                            [
+                            self.ContainerHover(self.objetos),
+                            self.icone_copy
+                        ], 
+                        spacing = 0,
+                        
+                                                            
+                    ),                                    
+                    ft.Stack(
+                        controls = [
+                            ft.Text("R", selectable=True, color="#BEBCE7", col = 1, left = 0,top = 2,),ft.Container(self.slides[f'r'],left = 5,top = 0),
+                            ft.Text("G", selectable=True, color="#BEBCE7", col = 1, left = 0,top = 27),ft.Container(self.slides[f'r'],left = 5,top = 25),
+                            ft.Text("B", selectable=True, color="#BEBCE7", col = 1, left = 0,top = 52),ft.Container(self.slides[f'r'],left = 5,top = 50),
+                            
+                        ], 
+                        alignment=ft.alignment.center,
+                        expand=True,
+                        # width=380,
+                        height=80,
+                    ),
+
+                ],
+                width=380,
+                spacing=0,
+                run_spacing=0,
+                horizontal_alignment='center',
+                tight=True,
+                # scroll=ft.ScrollMode.ADAPTIVE,
+                # expand=True,
+            ),
+            border=ft.border.all(1, 'grey800'),
+            border_radius=15,
+            padding=20,
+            expand_loose=True,
+            col =  {'xs':12, 'sm':7}
+            # height=400,
         )
 
+        self.content = ft.Column(
+            controls = [
+                ft.ResponsiveRow(
+                    controls = [
+                        self.color_box2,
+                        self.controles,
+                        
+                        ft.ResponsiveRow(
+                            [self.btn_exportar_cores, self.tema_escolhido], 
+                            alignment='center', 
+                            vertical_alignment='center'                                                      
+                        ),
+                        ft.ResponsiveRow(
+                            [self.btn_save,self.nome_tema,]
+                            , alignment='center',                           
+                        ),
+                         
+                        self.tabela_legenda,                   
+                    ],
+                    alignment='center', 
+                    columns=12
+                
+                ),                                                                                                                            
+            ], 
+            # alignment='center',
+            horizontal_alignment='center',
+            expand=True,
+            scroll=ft.ScrollMode.ADAPTIVE,  
+        )
+
+
+    def ContainerHover(self, componente):
+        def Hover(e):
+            if e.data == 'true':
+                componente.scale = 1.05
+                componente.bgcolor = 'grey700'
+                
+            else:
+                componente.scale = 1
+                componente.bgcolor = 'grey800'
+                
+            componente.update()
+        
+        return ft.Container(
+            content = componente,
+            on_hover = Hover,
+            col = componente.col
+        )
+
+
+
+    def ExibirLegendas(self, e):
+        self.tabela_legenda.visible = e.control.value
+        self.tabela_legenda.update()
+        e.control.label = "Exibir legendas" if not self.tabela_legenda.visible else "Ocultar legendas"
+        e.control.update()
+        self.update()
 
     def Cancelar(self, e):
         self.nome_tema.clean()
@@ -308,6 +423,7 @@ class SelectorColor(ft.Container):
     def Salvar(self, e):
         nome_tema = self.nome_tema.value
         if nome_tema not in ['', ' ', None]:#+list(self.arquiv.keys()):
+            self.GetArquivo()
             self.arquiv[nome_tema] = self.dic
             self.SalvarPickle(self.arquiv, self.nome_temas)
 
@@ -401,14 +517,48 @@ cores = {{
         else:
             self.gradiente.colors[0] = color
             setattr(self.color_box2, 'gradient', self.gradiente)
+        setattr(self.color_scheme, 'surface', color)            
         self.color_box2.update()
         self.update()
 
+
     def SetObjeto(self, e):
         self.slides['r'].data = e.control.value
         self.slides['g'].data = e.control.value
         self.slides['b'].data = e.control.value
 
+        self.SetColorFromHex(self.dic.get(e.control.value,"#000000"))
+
+
+    def SetColorFromHex(self, hex_color):
+        # Remove o caractere '#' se presente
+        hex_color = hex_color.lstrip('#')
+        
+        # Converte os valores hexadecimais para inteiros
+        r_value = int(hex_color[0:2], 16)
+        g_value = int(hex_color[2:4], 16)
+        b_value = int(hex_color[4:6], 16)
+        
+        # Seta os valores dos slides
+        self.slides['r'].value = r_value
+        self.slides['g'].value = g_value
+        self.slides['b'].value = b_value
+        
+        # Atualiza a cor e os valores exibidos
+        self.cor = f'#{r_value:02X}{g_value:02X}{b_value:02X}'
+        self.R.value = f'R ({r_value:02})'
+        self.G.value = f'G ({g_value:02})'
+        self.B.value = f'B ({b_value:02})'
+
+        self.update()
+
+        
+        # Atualiza os valores anteriores dos slides
+        self.prev_r = r_value
+        self.prev_g = g_value
+        self.prev_b = b_value
+
+
     def GerenciarSombras(self, e):
         if self.ativar_sombras.value:
             self.color_box.shadow = self.sombras
@@ -423,7 +573,12 @@ cores = {{
     def GerenciarGradiente(self, e):
         if self.ativar_gradiente.value:
             # cor = self.GetColorSafe('Gradiente') or 'blue'
+            if self.color_box2.bgcolor == None:
+                self.color_box2.bgcolor = 'black'
+            if self.gradiente.colors[1] == None:
+                self.gradiente.colors[1] = self.color_box2.bgcolor
             self.gradiente.colors[0] = self.color_box2.bgcolor
+            # print(self.gradiente.colors)
             self.color_box2.gradient = self.gradiente
         else:
             self.color_box2.gradient = None
@@ -447,6 +602,7 @@ cores = {{
     def update_color(self, e):
         if e.control.data:
             self.cor = f'#{int(self.slides['r'].value):02X}{int(self.slides['g'].value):02X}{int(self.slides['b'].value):02X}'
+
             self.datas[e.control.data](self.cor)
             self.update()
             self.page.update()
@@ -467,7 +623,10 @@ cores = {{
                     raise e
 
     def GetColorSafe(self, key):
-        v =  self.page.client_storage.get(f'{self.page.title}_{key}') or None
+        if __name__ == '__main__':
+            v =  self.page.client_storage.get(f'{self.page.title}_{key}') or None            
+        else:
+            v= None
         return v
 
     def did_mount(self):
@@ -477,10 +636,10 @@ cores = {{
         self.color_text.color = self.GetColorSafe('Texto')
         self.color_box.bgcolor = self.GetColorSafe('Container')
         self.color_box2.bgcolor = self.GetColorSafe('Fundo')
-        self.gradiente.colors = [self.color_box2.bgcolor, self.GetColorSafe('Gradiente')]
+        self.gradiente.colors = [self.color_box2.bgcolor, self.GetColorSafe('Gradiente')] if __name__ == '__main__' else ['black', 'black']
         self.sombras.color = self.GetColorSafe('Sombras')
         self.bordas = ft.border.all(1, self.GetColorSafe('Bordas'))
-    
+        self.botao.bgcolor = self.GetColorSafe('Botao')
 
         self.color_scheme.primary = self.GetColorSafe("primary")
         self.color_scheme.on_primary = self.GetColorSafe("on_primary")
@@ -491,7 +650,7 @@ cores = {{
         self.color_scheme.surface_variant = self.GetColorSafe("surface_variant")
         self.color_scheme.primary_container = self.GetColorSafe("primary_container")
         self.color_scheme.on_surface = self.GetColorSafe("on_surface")
-        self.color_scheme.surface = self.GetColorSafe("surface")
+        self.color_scheme.surface = self.color_box2.bgcolor
         self.text_theme.color = self.GetColorSafe("Texto")
 
 
@@ -500,10 +659,26 @@ cores = {{
         self.ativar_bordas.value = bool(self.GetColorSafe("Ativar Bordas"))
 
         self.page.theme = ft.Theme(
+
             color_scheme=self.color_scheme,
             text_theme = ft.TextTheme(
-                body_medium=self.text_theme  # Cor do texto padrão
-            )   
+                body_large = ft.TextStyle(),
+                body_medium=self.text_theme,  # Cor do texto padrão
+                body_small=ft.TextStyle(),
+                title_medium=ft.TextStyle(),
+
+            ),
+            scrollbar_theme=ft.ScrollbarTheme(
+                thickness = 10,
+                cross_axis_margin = -15,
+                min_thumb_length = 20,
+                track_color = 'grey500',
+                thumb_color = 'grey900',
+            ),
+            elevated_button_theme = ft.ElevatedButtonTheme(
+                # bgcolor = self.botao.bgcolor,
+                bgcolor = 'green',
+            )
         )
         self.dic = {
             "Container": self.color_box.bgcolor,
@@ -529,7 +704,8 @@ cores = {{
         }
 
         saida = Saida(self.page)
-        self.pprint = saida.pprint        
+        self.pprint = saida.pprint 
+        self.page.horizontal_alignment = 'center'
         self.page.update()
 
     def CarregarTema(self, e):
@@ -542,10 +718,16 @@ cores = {{
             self.color_text.color = self.dic.get('Texto')
             self.color_box.bgcolor = self.dic.get('Container')
             self.color_box2.bgcolor = self.dic.get('Fundo')
+            self.botao.bgcolor = self.dic.get('Botão')
 
             if isinstance(self.dic.get('Gradiente'), list):
                 self.dic['Gradiente'] = self.dic.get('Gradiente')[1]
-            self.gradiente.colors = [self.dic.get('Fundo'),self.dic.get('Gradiente')]
+            if not self.dic.get('Fundo'):
+                self.color_box2.bgcolor = 'black'
+            if not self.dic.get('Gradiente'):                
+                self.gradiente.colors = [self.dic.get('Fundo'),'black']
+            else:
+                self.gradiente.colors = [self.dic.get('Fundo'), self.dic.get('Gradiente')]
 
             self.sombras.color = self.dic.get('Sombras')
             self.bordas = ft.border.all(1, self.dic.get('Bordas'))
@@ -555,16 +737,41 @@ cores = {{
             self.ativar_bordas.value = self.dic.get("Ativar Bordas")
             if self.dic.get("Ativar Bordas"):
                 self.color_box.border = self.bordas
+            else:
+                self.color_box.border = None
 
             self.ativar_sombras.value = self.dic.get("Ativar Sombras")
             if self.dic.get("Ativar Sombras"):
                 self.color_box.shadow = self.sombras
+            else:
+                self.color_box.shadow = None
 
             self.ativar_gradiente.value = self.dic.get("Ativar Gradiente")
+            if self.color_box2.bgcolor == None:
+                self.color_box2.bgcolor = 'black'
             if self.dic.get("Ativar Gradiente"):
                 self.gradiente.colors[0] = self.color_box2.bgcolor
                 setattr(self.color_box2, 'gradient', self.gradiente)
+            else:
+                setattr(self.color_box2, 'gradient', None)
 
+            if not self.page.theme:
+                self.page.theme = ft.Theme(
+                    color_scheme=self.color_scheme,
+                    text_theme = ft.TextTheme(
+                        body_medium=self.text_theme  # Cor do texto padrão
+                    ),
+                    scrollbar_theme=ft.ScrollbarTheme(
+                        thickness = 10,
+                        cross_axis_margin = -15,
+                        min_thumb_length = 20,
+                        track_color = 'grey500',
+                        thumb_color = 'grey900',
+                    ),
+                    elevated_button_theme = ft.ElevatedButtonTheme(
+                        bgcolor = self.dic.get('Botão'),
+                    )
+                )
 
             self.color_scheme.primary = self.dic.get("primary")
             self.color_scheme.on_primary = self.dic.get("on_primary")
@@ -581,9 +788,10 @@ cores = {{
             self.update()
             self.page.update()
 
-    def GetArquivo(self):
+    def GetArquivo(self, caminho = None):        
         self.nome_temas = path.join(path.dirname(path.abspath(__file__)), 'Temas.plk')
-        self.arquiv = self.LerPickle(self.nome_temas) or  {  "black": {
+        caminho = caminho if caminho else self.nome_temas
+        self.arquiv = self.LerPickle(caminho) or  {  "black": {
                 "Container": "#226076",
                 "Fundo": "#1C1E1F",
                 "Texto":" #8CC34B",
@@ -603,14 +811,25 @@ cores = {{
                 "surface_variant":  None,
                 "primary_container":  None,
                 "on_surface":  None,
-                "surface":  None
+                "surface":  None,
+                "secondary": None,
+                "error":None,
+                "scrim": None,
+                "tertiary": None
+                
             }
         }
         
 
     def SalvarPickle(self,  var, nome):
-        with open(nome, 'wb') as arquivo:
-            dump(var, arquivo)
+        try:
+            if nome[-4:] != '.plk':
+                nome += '.plk'
+            with open(nome, 'wb') as arquivo:
+                dump(var, arquivo)
+           
+        except PermissionError:
+            self.pprint("Permissão negada. Execute o programa como administrador.")
 
     def LerPickle(self, nome):
         if path.isfile(nome):
@@ -761,6 +980,7 @@ def main(page):
     page.title = "Seletor de Cores"
     page.window.width = 700
     page.window.height = 300
+    page.horizontal_alignment = 'center'
     ConfirmarSaidaeResize(page = page, exibir=False, onlyresize=True)
     page.theme = ft.Theme(
         elevated_button_theme = ft.ElevatedButtonTheme(
